﻿/****************************************************************************
**
** Copyright (C) 2010-2011 Iteco Trading Srl
** All rights reserved.
** Contact: Iteco Trading Srl (alberto.plano@iteco.it)
**
** This file is part of the Itecad EDA software.
**
** Itecad is free software. You can redistribute it and/or modify it under the terms of
** the GNU Lesser General Public License (LGPLv2.1) as published by the Free Software Foundation
**
** This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
** See the GNU Lesser General Public License for more details.
**
** You should have received a copy of the GNU Lesser General Public License along with this software;
** if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
** If you have questions regarding the use of this file, please contact
** Iteco Trading Srl at alberto.plano@iteco.it
**
****************************************************************************/

#include "win_options.h"

extern	win_main	*w_main;

extern	QString	environment_language;

extern  QSettings   *program_settings;
extern  bool        y_axis_is_up;

win_options::win_options(QWidget *parent, Qt::WindowFlags tipo)
    : QDialog(parent, tipo)
{
    // Se questo QDialog viene creato con tipo == Qt::Dialog allora sono costretto ad avere il ? in alto a destra
    // Ciò forse è un bene perchè mi costringerà ad avere un minimo di help
    // Veder Qt::WindowContextHelpButtonHint per avere maggiori informazioni

    setWindowTitle(tr("Options"));
    //setSizeGripEnabled(true);
    setModal(true);

    QGridLayout	*layout = new QGridLayout(this);

    layout->addWidget(setup_language(),1,0);
    layout->addWidget(setup_axis(),2,0);
    layout->addLayout(setup_buttons(),3,0);
    layout->setSpacing(6);
    layout->setMargin(8);

}

QGroupBox *win_options::setup_language()
{
    QGroupBox *language = new QGroupBox(tr("Language"));
    QGridLayout	*layout_language = new QGridLayout();
    QLabel *language_text = new QLabel(tr("Change language:"));
    language_cb = new QComboBox();
    language_cb->addItem(tr("system language"));
    language_cb->addItem("Deutsch (de)");
    language_cb->addItem("English (en)");
    language_cb->addItem("Italiano (it)");
    int i = language_cb->findText(" ("+environment_language+")", Qt::MatchEndsWith);
    if(i > 0)
      language_cb->setCurrentIndex(i);
    layout_language->addWidget(language_text, 0, 0);
    layout_language->addWidget(language_cb, 0, 1);
    layout_language->setColumnStretch(2, TRUE);
    language->setLayout(layout_language);

    return language;
}

QGroupBox *win_options::setup_axis()
{
    QGroupBox *y_axis = new QGroupBox(tr("Y axis direction"));
    QGridLayout	*layout_y_axis = new QGridLayout();
    y_axis_up = new QRadioButton(tr("Up"), this);
    y_axis_down = new QRadioButton(tr("Down"), this);
    layout_y_axis->addWidget(y_axis_up, 0, 0);
    layout_y_axis->addWidget(y_axis_down, 1, 0);
    if (y_axis_is_up)
        y_axis_up->setChecked(TRUE);
    else
        y_axis_down->setChecked(TRUE);
    y_axis->setLayout(layout_y_axis);

    QGridLayout *gbox = new QGridLayout;
    gbox->addWidget(y_axis,0,0);
    gbox->setRowStretch(2,TRUE);

    return y_axis;
}

QHBoxLayout	*win_options::setup_buttons()
{
    QHBoxLayout	*L_comandi = new QHBoxLayout();
    L_comandi->setSpacing(6);
    L_comandi->setMargin(0);
    QSpacerItem	*L_comandi_molla = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);
    L_comandi->addItem(L_comandi_molla);
    QPushButton	*L_comandi_OK = new QPushButton(this);
    L_comandi_OK->setText(tr("Ok"));
    L_comandi->addWidget(L_comandi_OK);
    QPushButton	*L_comandi_Cancel = new QPushButton(this);
    L_comandi_Cancel->setText(tr("Cancel"));
    L_comandi->addWidget(L_comandi_Cancel);

    QObject::connect(L_comandi_OK, SIGNAL(clicked()), this, SLOT(accept()));
    QObject::connect(L_comandi_Cancel, SIGNAL(clicked()), this, SLOT(reject()));

    L_comandi_OK->setAutoDefault(TRUE);
    L_comandi_Cancel->setAutoDefault(FALSE);

    return L_comandi;
}

void	win_options::accept()
{
    environment_language = language_cb->currentText().section('(',1,1).remove(')');
    program_settings->setValue("environment_language", environment_language);

    y_axis_is_up = y_axis_up->isChecked();
    program_settings->setValue("y_axis_is_up", y_axis_is_up);

    QDialog::accept();
}
