﻿/****************************************************************************
**
** Copyright (C) 2010-2011 Iteco Trading Srl
** All rights reserved.
** Contact: Iteco Trading Srl (alberto.plano@iteco.it)
**
** This file is part of the Itecad EDA software.
**
** Itecad is free software. You can redistribute it and/or modify it under the terms of
** the GNU Lesser General Public License (LGPLv2.1) as published by the Free Software Foundation
**
** This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
** See the GNU Lesser General Public License for more details.
**
** You should have received a copy of the GNU Lesser General Public License along with this software;
** if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
** If you have questions regarding the use of this file, please contact
** Iteco Trading Srl at alberto.plano@iteco.it
**
****************************************************************************/

#include "win_part_select.h"

extern	win_main	*w_main;

win_part_select::win_part_select(QWidget *parent, Qt::WindowFlags tipo, bool is_available_part_input)
    : QDialog(parent, tipo)
{
    // Se questo QDialog viene creato con tipo == Qt::Dialog allora sono costretto ad avere il ? in alto a destra
    // Ciò forse è un bene perchè mi costringerà ad avere un minimo di help
    // Veder Qt::WindowContextHelpButtonHint per avere maggiori informazioni

    is_available_part = is_available_part_input;

    if (is_available_part)
        setWindowTitle(tr("Add"));
    else
        setWindowTitle(tr("New SSF"));
    //setSizeGripEnabled(true);
    setModal(true);

    QGridLayout	*layout = new QGridLayout(this);

    if (is_available_part)
        layout->addWidget(setup_part_available(),0,0, TRUE, FALSE);
    else
        layout->addWidget(setup_part_number(),0,0, TRUE, FALSE);
    layout->addLayout(setup_buttons(),1,0, TRUE, FALSE);
    layout->setSpacing(6);
    layout->setMargin(8);
}

QGroupBox *win_part_select::setup_part_available()
{
    QGroupBox	*group_part = new QGroupBox(tr("Add"));
    QGridLayout	*layout_part = new QGridLayout();

    add_available = new QRadioButton(tr("Available part of used component"));
    add_new = new QRadioButton(tr("New component"));

    part_number = new QComboBox(this);
    part_number->setEditable(FALSE);
    for (int i = 0; i < w_main->part_available_ident.count(); i++)
    {
        part_number->addItem(w_main->part_available_ident.at(i) + QString(QChar(64 + w_main->part_available_part.at(i))));
    }
    layout_part->addWidget(add_available, 0, 0);
    layout_part->addWidget(part_number, 0, 1);
    layout_part->addWidget(add_new, 1, 0);

    add_available->setChecked(TRUE);
    add_new->setChecked(FALSE);
    QObject::connect(add_available, SIGNAL(toggled(bool)), this, SLOT(change_add_type(bool)));
    QObject::connect(add_new, SIGNAL(toggled(bool)), this, SLOT(change_add_type(bool)));

    group_part->setLayout(layout_part);

    return group_part;
}

QGroupBox *win_part_select::setup_part_number()
{
    QGroupBox	*group_part = new QGroupBox(tr("Number of parts"));
    QGridLayout	*layout_part = new QGridLayout();

    QLabel *pn = new QLabel(this);
    pn->setText(tr("Number of parts:"));
    part_number = new QComboBox(this);
    part_number->setEditable(FALSE);
    part_number->addItem(tr("Single Body"));
    part_number->addItem(tr("2 part (A-B)"));
    part_number->addItem(tr("3 part (A-C)"));
    part_number->addItem(tr("4 part (A-D)"));
    part_number->addItem(tr("5 part (A-E)"));
    part_number->addItem(tr("6 part (A-F)"));
    part_number->addItem(tr("7 part (A-G)"));
    part_number->addItem(tr("8 part (A-H)"));
    part_number->addItem(tr("9 part (A-I)"));
    part_number->addItem(tr("10 part (A-J)"));
    part_number->addItem(tr("11 part (A-K)"));
    part_number->addItem(tr("12 part (A-L)"));
    part_number->addItem(tr("13 part (A-M)"));
    part_number->addItem(tr("14 part (A-N)"));
    part_number->addItem(tr("15 part (A-O)"));
    part_number->addItem(tr("16 part (A-P)"));
    layout_part->addWidget(pn, 0, 0);
    layout_part->addWidget(part_number, 0, 1);

    group_part->setLayout(layout_part);

    return group_part;
}

QHBoxLayout	*win_part_select::setup_buttons()
{
    QHBoxLayout	*L_comandi = new QHBoxLayout();
    L_comandi->setSpacing(6);
    L_comandi->setMargin(0);
    QSpacerItem	*L_comandi_molla = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);
    L_comandi->addItem(L_comandi_molla);
    QPushButton	*L_comandi_OK = new QPushButton(this);
    L_comandi_OK->setText(tr("Ok"));
    L_comandi->addWidget(L_comandi_OK);

    QObject::connect(L_comandi_OK, SIGNAL(clicked()), this, SLOT(accept()));

    L_comandi_OK->setAutoDefault(TRUE);

    return L_comandi;
}

void	win_part_select::change_add_type(bool /*checked*/)
{
    if (add_available->isChecked())
        part_number->setEnabled(TRUE);
    else
        part_number->setEnabled(FALSE);
}

void	win_part_select::accept()
{
    w_main->new_part_count = part_number->currentIndex() + 1;
    QDialog::accept();
}

void	win_part_select::reject()
{
    w_main->new_part_count = 0;
    QDialog::reject();
}

